@@ -607,6 +607,26 @@ labs_impute <- function(data) {
   data
 }
 
+#' Remove common prefix from the first column
+#'
+#' @keywords internal
+#'
+#' @param result A tibble with item names in the first column
+#' @return A tibble with the first column renamed to the prefix and the prefix removed from column values.
+labs_prefix <- function(result) {
+
+  prefix1 <- get_prefix(result[[1]])
+  result[[1]] = trim_prefix(result[[1]], prefix1)
+
+  # Rename first column
+  if (prefix1 != "") {
+    colnames(result)[1] <- trim_label(prefix1)
+  }
+
+  result
+}
+
+
 #' Get a common title for a column selection
 #'
 #' @keywords internal
@@ -616,7 +636,7 @@ labs_impute <- function(data) {
 #' @param default A character string used in case not prefix is found
 #' @return A character string.
 #' @importFrom rlang .data
-get_title <- function(data, cols, default=NULL) {
+get_title <- function(data, cols, default = NULL, max_length = 40) {
   labels <- data %>%
     codebook({{ cols }}) |>
     tidyr::drop_na("item_label") |>
@@ -637,7 +657,7 @@ get_title <- function(data, cols, default=NULL) {
     prefix <- default
   }
 
-  prefix
+  trunc_labels(prefix, max_length)
 }
 
 #' Get the numeric range from the labels
@@ -783,8 +803,15 @@ get_labels <- function(codes, values) {
 #'                   \code{c("Usage: in private context", "Usage: in work context")}.
 #'                   The common prefix would be \preformatted{"Usage: in "}, but it makes
 #'                   more sense to break it after the colon.
+#' @param minlength Minimum length of the prefix.
+#'                   Consider the following two items as an example:
+#'                   \code{c("coder one", "cg_act_write")}.
+#'                   The common prefix would be \preformatted{"c"},
+#'                   although the items have nothing in common.
+#'                   Requirung a minimum common prefix length should help in many cases.
+#'
 #' @return The longest common prefix of the strings.
-get_prefix <- function(x, ignore.case = FALSE, trim = FALSE, delimiters= c(":","\n")) {
+get_prefix <- function(x, ignore.case = FALSE, trim = FALSE, delimiters= c(":","\n"), minlength = 3) {
 
   x <- as.character(x)
   if (ignore.case) {
@@ -824,10 +851,23 @@ get_prefix <- function(x, ignore.case = FALSE, trim = FALSE, delimiters= c(":","
     prefix <- trim_label(prefix)
   }
 
+  if (nchar(prefix) < minlength) {
+    prefix <- ""
+  }
+
   prefix
 }
 
-length(c("asdasd","sdf"))
+#' Get a label for a key
+#'
+#' @keywords internal
+#'
+#' @param key The key
+#' @param options A list of labels with their keys
+#' @return The label from the options that matches the key
+map_label <- function(key, options = list()) {
+  options[[key]]
+}
 
 #' Wrap a string
 #'
